@@ -38,7 +38,7 @@ FIELDS = {
     int: INTEGER_LIKE,
     Decimal: (fields.DecimalField, {'widget': NUMERIC_WIDGET}),
     str: STRING_LIKE,
-    datetime: (fields.DateTimeField, {'widget': widgets.AdminSplitDateTime}),
+    datetime: (fields.SplitDateTimeField, {'widget': widgets.AdminSplitDateTime}),
     date: (fields.DateField, {'widget': widgets.AdminDateWidget}),
     time: (fields.TimeField, {'widget': widgets.AdminTimeWidget}),
     float: (fields.FloatField, {'widget': NUMERIC_WIDGET}),
@@ -47,7 +47,10 @@ FIELDS = {
 
 def parse_additional_fields(fields):
     for key in fields:
-        field = fields[key]
+        field = list(fields[key])
+
+        if len(field) == 1:
+            field.append({})
 
         field[0] = import_string(field[0])
 
@@ -58,6 +61,8 @@ def parse_additional_fields(fields):
             if 'widget_kwargs' in field[1]:
                 del field[1]['widget_kwargs']
 
+        fields[key] = field
+
     return fields
 
 
@@ -103,6 +108,10 @@ class ConstanceForm(forms.Form):
 
     def clean_version(self):
         value = self.cleaned_data['version']
+
+        if settings.IGNORE_ADMIN_VERSION_CHECK:
+            return value
+
         if value != self.initial['version']:
             raise forms.ValidationError(_('The settings have been modified '
                                           'by someone else. Please reload the '
@@ -112,6 +121,7 @@ class ConstanceForm(forms.Form):
 
 class ConstanceAdmin(admin.ModelAdmin):
     change_list_template = 'admin/constance/change_list.html'
+    change_list_form = ConstanceForm
 
     def get_urls(self):
         info = self.model._meta.app_label, self.model._meta.module_name
@@ -134,9 +144,9 @@ class ConstanceAdmin(admin.ModelAdmin):
         # Then update the mapping with actually values from the backend
         initial = dict(default_initial,
             **dict(config._backend.mget(settings.CONFIG.keys())))
-        form = ConstanceForm(initial=initial)
+        form = self.change_list_form(initial=initial)
         if request.method == 'POST':
-            form = ConstanceForm(data=request.POST, initial=initial)
+            form = self.change_list_form(data=request.POST, initial=initial)
             if form.is_valid():
                 form.save()
                 # In django 1.5 this can be replaced with self.message_user
