@@ -24,3 +24,7 @@ REDIS_CONNECTION_CLASS = getattr(settings, 'CONSTANCE_REDIS_CONNECTION_CLASS',
 REDIS_CONNECTION = getattr(settings, 'CONSTANCE_REDIS_CONNECTION', {})
 
 SUPERUSER_ONLY = getattr(settings, 'CONSTANCE_SUPERUSER_ONLY', True)
+
+IGNORE_ADMIN_VERSION_CHECK = getattr(settings,
+                                     'CONSTANCE_IGNORE_ADMIN_VERSION_CHECK',
+                                     False)
